import os
from pathlib import Path
from clear_console import clearConsole


def pypi_upload():
    while True:
        try:
            control_type = input('1、生成配置文件结构\n2、打包程序\n3、上传程序\n0、退出程序\n请通过序号选择需要的操作：')
            if int(control_type) == 1:
                changepath = input('一般这种文件都会放在根目录中,程序默认使用上一级目录进行创建，是否手动指定根目录？Y为重新指定，其他任意字符为不指定：')
                if changepath.lower() == 'y':
                    filepath = input('请输入文件路径：')+'/'
                else:
                    filepath = '../'
                mkfileList = ['setup.py', 'LICENSE.txt', 'README.md']
                for filename in mkfileList:
                    Path(filepath+filename).touch(exist_ok=True)
                    if filename == 'setup.py':
                        with open(filepath+filename, 'w', encoding='utf-8') as f:
                            f.write('''import setuptools
with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()
setuptools.setup(
    name="xxx",    # 包名
    version="0.1",  # 版本
    author="hzz",   # 作者
    author_email="1538379200@qq.com",    # 邮箱
    description="项目介绍",
    long_description=long_description,  # 长介绍，为编写的README
    long_description_content_type="text/markdown",  # 使用介绍文本
    url="",     # github等项目地址
    packages=setuptools.find_packages(),    # 自动查找包，手动写也可
    install_requires=['setuptools>=60.8.1', 'wheel>=0.37.1', 'twine>=3.8.0'],    # 安装此包所需的依赖
    entry_points={
        'console_scripts': [        # 命令行运行代码
            'pypi-up=pypk.main:run'
        ],
    },
    classifiers=(       # 其他的配置项
        "Programming Language :: Python :: 3",      # 限制pytest编程语言，版本为3
        "License :: OSI Approved :: MIT License",   # 使用MIT的开源协议(手动添加协议后修改此项)
        "Operating System :: OS Independent",   # 系统要求
    ),
)''')
                    else:
                        pass
                print('文件创建完成，请修改配置项和开源协议等')
            elif int(control_type) == 2:
                basepath = input('指定程序根目录,不输入则默认上一级目录：')
                print('正在打包文件……')
                if ':' in basepath:
                    sdisk = basepath.split(':')[0]
                    os.system(f'cd {sdisk}: && cd {basepath} &&　python setup.py sdist bdist_wheel')
                elif basepath == '':
                    os.system('cd .. && python setup.py sdist bdist_wheel')
                else:
                    os.system(f'cd {basepath} && python setup.py sdist bdist_wheel')
                print('文件打包操作已完成')
            elif int(control_type) == 3:
                workpath = input('请输入当前文件根目录,不输入则默认上一级目录：')
                print('准备进行文件上传')
                if ':' in workpath:
                    sdisk = workpath.split(':')[0]
                    os.system(f'cd {sdisk}: && cd {workpath} && twine upload dist/*')
                elif workpath == '':
                    os.system('cd .. && twine upload dist/*')
                else:
                    os.system(f'cd {workpath} && twine upload dist/*')
                print('已完成文件上传程序')
            elif int(control_type) == 0:
                clearConsole()
                break
        except:
            print('输入的序号有误，请重新输入')

# if __name__ == '__main__':
#     pypi_upload()






from pypi_update import pypi_update
from pypi_upload import pypi_upload
import os
from clear_console import clearConsole

def run():
    while True:
        step = input('1、更新python包\n2、上传项目至pypi\n0、退出程序\n请选择需要的操作：')
        if step == '1':
            clearConsole()
            pypi_update()
        elif step == '2':
            clearConsole()
            pypi_upload()
        elif step == '0':
            clearConsole()
            break
        else:
            print('输入信息有误')


if __name__ == '__main__':
    run()




import setuptools
with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()
setuptools.setup(
    name="pypk_up",    # 包名
    version="0.0.1",  # 版本
    author="测码范晔",   # 作者
    author_email="1538379200@qq.com",    # 邮箱
    description="一个管理python包和上传程序的扩展工具",
    long_description=long_description,  # 长介绍，为编写的README
    long_description_content_type="text/markdown",  # 使用介绍文本
    url="",     # github等项目地址
    packages=setuptools.find_packages(),    # 自动查找包，手动写也可
    install_requires=['setuptools>=60.8.1', 'wheel>=0.37.1', 'twine>=3.8.0'],    # 安装此包所需的依赖
    entry_points={
        'console_scripts': [        # 命令行运行代码
            'pypk_up=pypk.main:run'
        ],
    },
    classifiers=(       # 其他的配置项
        "Programming Language :: Python :: 3",      # 限制pytest编程语言，版本为3
        "License :: OSI Approved :: MIT License",   # 使用MIT的开源协议(手动添加协议后修改此项)
        "Operating System :: OS Independent",   # 系统要求
    ),
)


import subprocess
import os
from clear_console import clearConsole


def pypi_update():
    print('使用pip更新程序前，请确保已设置pip环境变量')
    qinghua = 'https://pypi.tuna.tsinghua.edu.cn/simple'
    kexuejishu = 'https://pypi.mirrors.ustc.edu.cn/simple'
    douban = 'http://pypi.doubanio.com/simple/'
    tengxun = 'https://mirrors.cloud.tencent.com/pypi/simple/'
    ali = 'https://mirrors.aliyun.com/pypi/simple/'
    mirrorList = [qinghua, kexuejishu, douban, tengxun, ali]
    print('使用镜像源安装：\n1、清华镜像源\n2、科学大学镜像源\n3、豆瓣镜像源\n4、腾讯镜像源\n5、阿里镜像源\n0、自定义镜像源\n如果不需要镜像源，可以选择自定义，直接回车')
    useMirror = ''
    while True:
        mirror = input('请输入镜像源：')
        try:
            if int(mirror) == 0:
                a = input('请输入自定义镜像源：')
                useMirror = a
            elif int(mirror) > 0:
                useMirror = mirrorList[int(mirror)-1]
            break
        except:
            print('输入有误，请重新输入')
    print('正在查找可更新数据源……')
    get_pakeages = os.popen('pip list --outdate')
    listPakeages = list(get_pakeages)
    # show_updatePk = [listPakeages[x].split(' ')[0] for x in range(2, len(listPakeages)-1)]
    show_updatePk = []

    for i in range(2, len(listPakeages) - 1):
        pk = listPakeages[i].split(' ')[0]
        show_updatePk.append(pk)
        print(i - 1, '、', pk)

    print('输入序号可以更新单个包\n输入0更新全部\n输入-x为过滤第x项(x为前置的序号)\n输入任意非数字退出程序')
    while True:
        try:
            userOrder = input('请输入需要的操作：')
            print('')
            if int(userOrder) == 0:
                if useMirror == '':
                    for pakeage in show_updatePk:
                        subprocess.call('pip install --upgrade ' + pakeage, shell=True)
                else:
                    for pakeage in show_updatePk:
                        subprocess.call('pip install --upgrade ' + pakeage + ' -i '+useMirror, shell=True)
                print('操作完成')
                clearConsole()
                break
            elif int(userOrder) > 0:
                try:
                    if useMirror == '':
                        subprocess.call('pip install --upgrade ' + show_updatePk[int(userOrder) - 1], shell=True)
                    else:
                        subprocess.call('pip install --upgrade ' + show_updatePk[int(userOrder) - 1] + ' -i ' + useMirror, shell=True)
                    print('已操作：', show_updatePk[int(userOrder)-1])
                    print('更新数据：')
                    for pIndex, p in enumerate(show_updatePk):
                        print(pIndex+1, '、', p)
                except:
                    print('输入的数字有误，可能没有此序号')
            elif int(userOrder) < 0:
                try:
                    removeList = userOrder.split('-')[1]
                    pakeNum = int(removeList)
                    del show_updatePk[pakeNum-1]
                    print('更新数据：')
                    for pakeIndex, pakeage in enumerate(show_updatePk):
                        print(pakeIndex+1, '、', pakeage)
                except:
                    print('输入的序号有误或者符号错误')
        except:
            print('取消更新')
            clearConsole()
            break

# if __name__ == '__main__':
#     pypi_update()